=======
zemfrog
=======


.. image:: https://img.shields.io/pypi/v/zemfrog.svg
        :target: https://pypi.python.org/pypi/zemfrog

.. image:: https://img.shields.io/travis/zemfrog/zemfrog.svg
        :target: https://travis-ci.com/zemfrog/zemfrog

.. image:: https://readthedocs.org/projects/zemfrog/badge/?version=latest
        :target: https://zemfrog.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status



Zemfrog is a simple framework for building web or APIs with flask. 
Which focuses on an application structure that can be managed easily.
We believe zemforg can speed up your work with flask and please help us develop this framework!

* Free software: MIT license
* Documentation: https://zemfrog.readthedocs.io.


Notes
-----

It should be noted. currently, the zemfrog project is still under development. So we are not responsible for the instability of zemfrog features.


Features
--------

* Solid application structure.
* Automation creates APIs based on tables in the database.
* Automation creates schema models for your ORM.
* Easy to add your commands.
* Easy to add extensions.
* Easy to add task queue to celery.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
